from distutils.core import setup

setup(
    name = 'maju_test',
    version = '1.4.1',
    py_modules = ['maju_test'],
    author = 'maju',
    author_email = 'hfpython@headfirstlabs.com',
    url = 'http://www.headfirstlabs.com',
    description= 'It\'s test program from Head First book',
)
